
### Sending the email newsletter

We need to ask the user for the sender email configuration. Some may be in the
plugin configuration in the `mkdocs.yml` while others (at least the password)
should be taken from environmental variables.

For each article selected an email is sent.
